==> pvfs-1.5.3-pre1.tgz: pvfs-1.5.3-pre1/iod/jobs.h <==
/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See COPYING in top-level directory.
 */


#ifndef BUILD_JOB_H
#define BUILD_JOB_H

#include <config.h>
#include <jlist.h>
#include <req.h>

/* prototypes */
jinfo_p build_job(int sock, ireq_p, finfo_p);
jinfo_p build_list_job(int sock, ireq_p r_p, finfo_p f_p);
int do_job(int sock, jinfo_p j_p);
int j_merge(jinfo_p j1_p, jinfo_p j2_p);

/* NEXTPL() modifies fl */
/* Description of cryptic variables:
 * pl - 	partition location; location (offset) into file containing
 *		  	data for this partition
 *	fl	-	file location; location (offset) into the logical file that 
 *			is defined by the application's view (?)
 * rl -	relative location (?); whatever you call it, it is the offset
 * 		in the file if the partitions were spliced together into one
 *			correctly ordered file (?).
 * df -	I don't know yet.
 */
#define NEXTPL(fp,rl,fl) do { \
	register int64_t __df, \
	         __st, /* size of a stride in bytes */ \
            __off; /* loc. in "whole file" where file on this node starts */ \
	if ((__df = ((rl - (__off = (fp->p_stat.soff + fp->pnum*fp->p_stat.ssize))) \
	% (__st = fp->p_stat.pcount*fp->p_stat.ssize))) < 0) \
	{ \
		fl = __off; \
	} \
	else if (__df >= fp->p_stat.ssize) fl = rl + (__st - __df); \
	else fl = rl; \
} while(0)

#define FLTOPL(fp,fl) (((fl - fp->p_stat.soff) / fp->p_stat.ssize) \
	/ fp->p_stat.pcount * fp->p_stat.ssize \
	+ ((fl - fp->p_stat.soff) % fp->p_stat.ssize))

#define TOPEND(fp,pl) (fp->p_stat.ssize - (pl % fp->p_stat.ssize))

#endif

==> pvfs-1.5.4.tgz: pvfs-1.5.4/iod/jobs.h <==
/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See COPYING in top-level directory.
 */


#ifndef BUILD_JOB_H
#define BUILD_JOB_H

#include <config.h>
#include <jlist.h>
#include <req.h>

/* prototypes */
jinfo_p build_job(int sock, ireq_p, finfo_p);
jinfo_p build_list_job(int sock, ireq_p r_p, finfo_p f_p, int64_t *offs,
		       int32_t *lens);
int do_job(int sock, jinfo_p j_p);
int j_merge(jinfo_p j1_p, jinfo_p j2_p);

/* NEXTPL() modifies fl */
/* Description of cryptic variables:
 * pl - 	partition location; location (offset) into file containing
 *		  	data for this partition
 *	fl	-	file location; location (offset) into the logical file that 
 *			is defined by the application's view (?)
 * rl -	relative location (?); whatever you call it, it is the offset
 * 		in the file if the partitions were spliced together into one
 *			correctly ordered file (?).
 * df -	I don't know yet.
 */
#define NEXTPL(fp,rl,fl) do { \
	register int64_t __df, \
	         __st, /* size of a stride in bytes */ \
            __off; /* loc. in "whole file" where file on this node starts */ \
	if ((__df = ((rl - (__off = (fp->p_stat.soff + fp->pnum*fp->p_stat.ssize))) \
	% (__st = fp->p_stat.pcount*fp->p_stat.ssize))) < 0) \
	{ \
		fl = __off; \
	} \
	else if (__df >= fp->p_stat.ssize) fl = rl + (__st - __df); \
	else fl = rl; \
} while(0)

#define FLTOPL(fp,fl) (((fl - fp->p_stat.soff) / fp->p_stat.ssize) \
	/ fp->p_stat.pcount * fp->p_stat.ssize \
	+ ((fl - fp->p_stat.soff) % fp->p_stat.ssize))

#define TOPEND(fp,pl) (fp->p_stat.ssize - (pl % fp->p_stat.ssize))

#endif

/*
 * Local variables:
 *  c-indent-level: 3
 *  c-basic-offset: 3
 *  tab-width: 3
 * End:
 */
